@@ -11,12 +11,14 @@ from mitosheet.public.v3.types.float import cast_string_to_float
 def cast_str_to_int(s: str) -> Optional[int]:
     f = cast_string_to_float(s)
     if f is None:
-        return None
+        raise make_invalid_param_type_conversion_error(s, 'int')
     else:
         return int(f)
 
 def cast_to_int(unknown: Union[str, int, float, bool, datetime, timedelta]) -> Optional[int]:
-    if isinstance(unknown, str):
+    if isinstance(unknown, bool):
+        return int(unknown)
+    elif isinstance(unknown, str):
         return cast_str_to_int(unknown)
     elif isinstance(unknown, int):
         return unknown
@@ -26,7 +28,4 @@ def cast_to_int(unknown: Union[str, int, float, bool, datetime, timedelta]) -> O
         except:
             raise make_invalid_param_type_conversion_error(unknown, 'int')
 
-    elif isinstance(unknown, bool):
-        return int(unknown)
-
     return None
\ No newline at end of file
